==> qtjambi-location-debuginfo-macos-5.15.17.jar: sources/QtJambiLocation/QPlaceRatings_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtLocation/qplaceratings.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambiLocation/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QPlaceRatings(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QPlaceRatings")
    QPlaceRatings *_ptr = reinterpret_cast<QPlaceRatings *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QPlaceRatings()
void __qt_construct_QPlaceRatings_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QPlaceRatings()")
    Q_UNUSED(__java_arguments)
    QPlaceRatings *__qt_this = new(__qtjambi_ptr) QPlaceRatings();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// new QPlaceRatings(QPlaceRatings)
void __qt_construct_QPlaceRatings_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QPlaceRatings(QPlaceRatings)")
    jobject other0 = __java_arguments[0].l;
    const QPlaceRatings& __qt_other0 = qtjambi_cast<const QPlaceRatings& >(__jni_env, other0);
    QPlaceRatings *__qt_this = new(__qtjambi_ptr) QPlaceRatings(__qt_other0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QPlaceRatings
void __qt_destruct_QPlaceRatings(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QPlaceRatings")
    reinterpret_cast<QPlaceRatings*>(ptr)->~QPlaceRatings();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QPlaceRatings::QPlaceRatings()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceRatings_initialize_1native__Lio_qt_location_QPlaceRatings_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPlaceRatings::QPlaceRatings()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QPlaceRatings_0, sizeof(QPlaceRatings), typeid(QPlaceRatings), false, &deleter_QPlaceRatings, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QPlaceRatings::QPlaceRatings(QPlaceRatings)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceRatings_initialize_1native__Lio_qt_location_QPlaceRatings_2Lio_qt_location_QPlaceRatings_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPlaceRatings::QPlaceRatings(QPlaceRatings)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QPlaceRatings_1, sizeof(QPlaceRatings), typeid(QPlaceRatings), false, &deleter_QPlaceRatings, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QPlaceRatings::average()const
extern "C" Q_DECL_EXPORT jdouble JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceRatings_average_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jdouble __java_return_value{0};
    QTJAMBI_TRY {
        const QPlaceRatings *__qt_this = QtJambiAPI::objectFromNativeId<QPlaceRatings>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPlaceRatings::average()const", __qt_this)
        qreal __qt_return_value = __qt_this->average();
        __java_return_value = jdouble(__qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QPlaceRatings::count()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceRatings_count_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QPlaceRatings *__qt_this = QtJambiAPI::objectFromNativeId<QPlaceRatings>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPlaceRatings::count()const", __qt_this)
        __java_return_value = __qt_this->count();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QPlaceRatings::isEmpty()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceRatings_isEmpty_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QPlaceRatings *__qt_this = QtJambiAPI::objectFromNativeId<QPlaceRatings>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPlaceRatings::isEmpty()const", __qt_this)
        __java_return_value = __qt_this->isEmpty();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QPlaceRatings::maximum()const
extern "C" Q_DECL_EXPORT jdouble JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceRatings_maximum_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jdouble __java_return_value{0};
    QTJAMBI_TRY {
        const QPlaceRatings *__qt_this = QtJambiAPI::objectFromNativeId<QPlaceRatings>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPlaceRatings::maximum()const", __qt_this)
        qreal __qt_return_value = __qt_this->maximum();
        __java_return_value = jdouble(__qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QPlaceRatings::operator=(QPlaceRatings)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceRatings_assign_1native_1cref_1QPlaceRatings__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QPlaceRatings *__qt_this = QtJambiAPI::objectFromNativeId<QPlaceRatings>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPlaceRatings::operator=(QPlaceRatings)", __qt_this)
        const QPlaceRatings& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QPlaceRatings>(other0);
        (*__qt_this) = __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QPlaceRatings::operator==(QPlaceRatings)const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceRatings_operator_1equal_1native_1cref_1QPlaceRatings_1constfct__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QPlaceRatings *__qt_this = QtJambiAPI::objectFromNativeId<QPlaceRatings>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPlaceRatings::operator==(QPlaceRatings)const", __qt_this)
        const QPlaceRatings& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QPlaceRatings>(other0);
        __java_return_value = (*__qt_this) == __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QPlaceRatings::setAverage(qreal)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceRatings_setAverage_1native_1qreal__JD)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jdouble average0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QPlaceRatings *__qt_this = QtJambiAPI::objectFromNativeId<QPlaceRatings>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPlaceRatings::setAverage(qreal)", __qt_this)
        __qt_this->setAverage(static_cast<qreal>(average0));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QPlaceRatings::setCount(int)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceRatings_setCount_1native_1int__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint count0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QPlaceRatings *__qt_this = QtJambiAPI::objectFromNativeId<QPlaceRatings>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPlaceRatings::setCount(int)", __qt_this)
        __qt_this->setCount(static_cast<int>(count0));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QPlaceRatings::setMaximum(qreal)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceRatings_setMaximum_1native_1qreal__JD)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jdouble max0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QPlaceRatings *__qt_this = QtJambiAPI::objectFromNativeId<QPlaceRatings>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPlaceRatings::setMaximum(qreal)", __qt_this)
        __qt_this->setMaximum(static_cast<qreal>(max0));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceRatings_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QPlaceRatings *__qt_this = QtJambiAPI::objectFromNativeId<QPlaceRatings>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(hashValue);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceRatings_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QPlaceRatings *__qt_this = QtJambiAPI::objectFromNativeId<QPlaceRatings>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QPlaceRatings(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QPlaceRatings>("QPlaceRatings", "io/qt/location/QPlaceRatings");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QPlaceRatings, {
        ConstructorInfo(&__qt_construct_QPlaceRatings_0, nullptr)
       ,ConstructorInfo(&__qt_construct_QPlaceRatings_1, "Lio/qt/location/QPlaceRatings;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QPlaceRatings);
    registerMetaType<QPlaceRatings>("QPlaceRatings");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-location-debuginfo-macos-5.15.20.jar: sources/QtJambiLocation/QPlaceRatings_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtLocation/qplaceratings.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambiLocation/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QPlaceRatings(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QPlaceRatings")
    QPlaceRatings *_ptr = reinterpret_cast<QPlaceRatings *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QPlaceRatings()
void __qt_construct_QPlaceRatings(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QPlaceRatings()")
    Q_UNUSED(__java_arguments)
    QPlaceRatings *__qt_this = new(__qtjambi_ptr) QPlaceRatings();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QPlaceRatings::QPlaceRatings()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceRatings_initialize_1native__Lio_qt_location_QPlaceRatings_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPlaceRatings::QPlaceRatings()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QPlaceRatings, sizeof(QPlaceRatings), typeid(QPlaceRatings), false, &deleter_QPlaceRatings, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QPlaceRatings(QPlaceRatings)
void __qt_construct_QPlaceRatings_cref_QPlaceRatings(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QPlaceRatings(QPlaceRatings)")
    jobject other0 = __java_arguments[0].l;
    const QPlaceRatings& __qt_other0 = qtjambi_cast<const QPlaceRatings& >(__jni_env, other0);
    QPlaceRatings *__qt_this = new(__qtjambi_ptr) QPlaceRatings(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QPlaceRatings::QPlaceRatings(QPlaceRatings)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceRatings_initialize_1native__Lio_qt_location_QPlaceRatings_2Lio_qt_location_QPlaceRatings_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPlaceRatings::QPlaceRatings(QPlaceRatings)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QPlaceRatings_cref_QPlaceRatings, sizeof(QPlaceRatings), typeid(QPlaceRatings), false, &deleter_QPlaceRatings, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QPlaceRatings
void __qt_destruct_QPlaceRatings(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QPlaceRatings")
    reinterpret_cast<QPlaceRatings*>(ptr)->~QPlaceRatings();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QPlaceRatings::average()const
extern "C" Q_DECL_EXPORT jdouble JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceRatings_average_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jdouble __java_return_value{0};
    QTJAMBI_TRY {
        const QPlaceRatings *__qt_this = QtJambiAPI::objectFromNativeId<QPlaceRatings>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPlaceRatings::average()const", __qt_this)
        qreal __qt_return_value = __qt_this->average();
        __java_return_value = jdouble(__qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QPlaceRatings::count()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceRatings_count_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QPlaceRatings *__qt_this = QtJambiAPI::objectFromNativeId<QPlaceRatings>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPlaceRatings::count()const", __qt_this)
        __java_return_value = __qt_this->count();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QPlaceRatings::isEmpty()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceRatings_isEmpty_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QPlaceRatings *__qt_this = QtJambiAPI::objectFromNativeId<QPlaceRatings>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPlaceRatings::isEmpty()const", __qt_this)
        __java_return_value = __qt_this->isEmpty();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QPlaceRatings::maximum()const
extern "C" Q_DECL_EXPORT jdouble JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceRatings_maximum_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jdouble __java_return_value{0};
    QTJAMBI_TRY {
        const QPlaceRatings *__qt_this = QtJambiAPI::objectFromNativeId<QPlaceRatings>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPlaceRatings::maximum()const", __qt_this)
        qreal __qt_return_value = __qt_this->maximum();
        __java_return_value = jdouble(__qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QPlaceRatings::operator=(QPlaceRatings)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceRatings_assign_1native_1cref_1QPlaceRatings__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QPlaceRatings *__qt_this = QtJambiAPI::objectFromNativeId<QPlaceRatings>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPlaceRatings::operator=(QPlaceRatings)", __qt_this)
        const QPlaceRatings& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QPlaceRatings>(other0);
        (*__qt_this) = __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QPlaceRatings::operator==(QPlaceRatings)const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceRatings_equals_1native_1cref_1QPlaceRatings_1constfct__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QPlaceRatings *__qt_this = QtJambiAPI::objectFromNativeId<QPlaceRatings>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPlaceRatings::operator==(QPlaceRatings)const", __qt_this)
        const QPlaceRatings& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QPlaceRatings>(other0);
        __java_return_value = (*__qt_this) == __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QPlaceRatings::setAverage(qreal)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceRatings_setAverage_1native_1qreal__JD)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jdouble average0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QPlaceRatings *__qt_this = QtJambiAPI::objectFromNativeId<QPlaceRatings>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPlaceRatings::setAverage(qreal)", __qt_this)
        __qt_this->setAverage(static_cast<qreal>(average0));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QPlaceRatings::setCount(int)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceRatings_setCount_1native_1int__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint count0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QPlaceRatings *__qt_this = QtJambiAPI::objectFromNativeId<QPlaceRatings>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPlaceRatings::setCount(int)", __qt_this)
        __qt_this->setCount(static_cast<int>(count0));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QPlaceRatings::setMaximum(qreal)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceRatings_setMaximum_1native_1qreal__JD)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jdouble max0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QPlaceRatings *__qt_this = QtJambiAPI::objectFromNativeId<QPlaceRatings>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPlaceRatings::setMaximum(qreal)", __qt_this)
        __qt_this->setMaximum(static_cast<qreal>(max0));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceRatings_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QPlaceRatings *__qt_this = QtJambiAPI::objectFromNativeId<QPlaceRatings>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(hashValue);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceRatings_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QPlaceRatings *__qt_this = QtJambiAPI::objectFromNativeId<QPlaceRatings>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QPlaceRatings(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QPlaceRatings>("QPlaceRatings", "io/qt/location/QPlaceRatings");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QPlaceRatings, {
        ConstructorInfo(&__qt_construct_QPlaceRatings, nullptr)
       ,ConstructorInfo(&__qt_construct_QPlaceRatings_cref_QPlaceRatings, "Lio/qt/location/QPlaceRatings;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QPlaceRatings);
    registerMetaType<QPlaceRatings>("QPlaceRatings");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
